<?php
/**
 * VW Newspaper functions and definitions
 *
 * @package VW Newspaper
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if ( ! function_exists( 'vw_newspaper_setup' ) ) :
 
function vw_newspaper_setup() {

	$GLOBALS['content_width'] = apply_filters( 'vw_newspaper_content_width', 640 );
	
	load_theme_textdomain( 'vw-newspaper', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('vw-newspaper-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'vw-newspaper' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', vw_newspaper_font_url() ) );
}
endif;

// Theme Activation Notice
	global $pagenow;

	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
	add_action( 'admin_notices', 'vw_newspaper_activation_notice' );
	}


	add_action( 'after_setup_theme', 'vw_newspaper_setup' );

	// Notice after Theme Activation
	function vw_newspaper_activation_notice() {
	echo '<div class="notice notice-success is-dismissible welcome-notice">';
	echo '<h3>'. esc_html__( 'Warm Greetings to you!!', 'vw-newspaper' ) .'</h3>';
	echo '<p>'. esc_html__( 'Thank you for choosing VW Newspaper Theme. Would like to have you on our Welcome page so that you can reap all the benefits of our VW Newspaper Theme.', 'vw-newspaper' ) .'</p>';
	echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=vw_newspaper_guide' ) ) .'" class="button button-primary">'. esc_html__( 'GET STARTED', 'vw-newspaper' ) .'</a></p>';
	echo '</div>';

}

/* Theme Widgets Setup */
function vw_newspaper_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'vw-newspaper' ),
		'description'   => __( 'Appears on blog page sidebar', 'vw-newspaper' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'vw-newspaper' ),
		'description'   => __( 'Appears on page sidebar', 'vw-newspaper' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'vw-newspaper' ),
		'description'   => __( 'Appears on page sidebar', 'vw-newspaper' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'vw-newspaper' ),
		'description'   => __( 'Appears on footer 1', 'vw-newspaper' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'vw-newspaper' ),
		'description'   => __( 'Appears on footer 2', 'vw-newspaper' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'vw-newspaper' ),
		'description'   => __( 'Appears on footer 3', 'vw-newspaper' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'vw-newspaper' ),
		'description'   => __( 'Appears on footer 4', 'vw-newspaper' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Social Icon', 'vw-newspaper' ),
		'description'   => __( 'Appears on footer', 'vw-newspaper' ),
		'id'            => 'social-icon',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vw_newspaper_widgets_init' );

/* Theme Font URL */
function vw_newspaper_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800';
	$font_family[] = 'Gabriela';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/* Theme enqueue scripts */
function vw_newspaper_scripts() {
	wp_enqueue_style( 'vw-newspaper-font', vw_newspaper_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'vw-newspaper-basic-style', get_stylesheet_uri() );	
	wp_enqueue_style( 'vw-newspaper-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'vw-newspaper-custom-scripts-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'SmoothScroll', get_template_directory_uri() . '/js/SmoothScroll.js', array('jquery') );
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/css/owl.carousel.css' );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.js', array('jquery'), '', true);
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Enqueue the Dashicons script */
	wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'vw_newspaper_scripts' );

function vw_newspaper_ie_stylesheet(){
	wp_enqueue_style('vw-newspaper-ie', get_template_directory_uri().'/css/ie.css');
	wp_style_add_data( 'vw-newspaper-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','vw_newspaper_ie_stylesheet');

/*radio button sanitization*/

function vw_newspaper_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Excerpt Limit Begin */
function vw_newspaper_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

define('VW_NEWSPAPER_FREE_THEME_DOC','https://vwthemes.com/docs/free-vw-newspaper/','vw-newspaper');
define('VW_NEWSPAPER_SUPPORT','https://wordpress.org/support/theme/vw-newspaper/','vw-newspaper');
define('VW_NEWSPAPER_REVIEW','https://wordpress.org/support/theme/vw-newspaper/reviews','vw-newspaper');
define('VW_NEWSPAPER_BUY_NOW','https://www.vwthemes.com/themes/newspaper-wordpress-theme/','vw-newspaper');
define('VW_NEWSPAPER_LIVE_DEMO','https://www.vwthemes.net/vw-newspaper-pro/','vw-newspaper');
define('VW_NEWSPAPER_PRO_DOC','https://vwthemes.com/docs/vw-newspaper-pro/','vw-newspaper');
define('VW_NEWSPAPER_FAQ','https://www.vwthemes.com/faqs/','vw-newspaper');
define('VW_NEWSPAPER_CONTACT','https://www.vwthemes.com/contact/','vw-newspaper');
define('VW_NEWSPAPER_CHILD_THEME','https://developer.wordpress.org/themes/advanced-topics/child-themes/','vw-newspaper');
define('VW_NEWSPAPER_CREDIT','https://www.vwthemes.com/themes/free-newspaper-wordpress-theme/','vw-newspaper');

if ( ! function_exists( 'vw_newspaper_credit' ) ) {
	function vw_newspaper_credit(){
		echo "<a href=".esc_url(VW_NEWSPAPER_CREDIT)." target='_blank'>".esc_html__('Newspaper Theme.','vw-newspaper')."</a>";
	}
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'vw_newspaper_loop_columns');
if (!function_exists('vw_newspaper_loop_columns')) {
function vw_newspaper_loop_columns() {
return 3; // 3 products per row
}
}

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Social Custom Widgets */
require get_template_directory() . '/inc/custom-widgets/social-icon.php';

/* Implement the About theme page */
require get_template_directory() . '/inc/getstart/getstart.php';

/* typography */
require get_template_directory() . '/inc/typography/ctypo.php';